@@ -5,6 +5,7 @@ import sys
 
 import time
 import base64
+import sys
 
 #
 try:
@@ -436,6 +437,9 @@ class Metaclass(type):
 
 class WrapperBase(metaclass=Metaclass):
     config = {}
+    requestCls = None
+
+    responseCls = None
 
     def __init__(self, legacy=True, is_aipaas=True, keep_schema_default_value=True):
         # 仅测试调试用
@@ -447,6 +451,11 @@ class WrapperBase(metaclass=Metaclass):
         self.is_aipaas = is_aipaas
         self.keep_schema_default_value = keep_schema_default_value
         self._schema = None
+        self.printPythonInfo()
+
+    def printPythonInfo(self):
+        print("### Current Using Python: %s ### " % sys.executable)
+        print("### Current Python Version: %s ###" % sys.version)
 
     def gradio(self):
         from aiges.gradio_util.component import GradioComponent
@@ -672,6 +681,7 @@ class WrapperBase(metaclass=Metaclass):
             self.params_test_values.update()
             self.params_test_values[param.key] = param.test_value
         return params_fields, required_params
+
     def _parse_params_v2(self, serviceId, accepets_payloads):
         params = self.__mappings__.get('params', [])
         a_dict = {}
@@ -699,8 +709,6 @@ class WrapperBase(metaclass=Metaclass):
             # else:
             #     _dict[param.key] = param.test_value
 
-
-
         # 这里是处理 accept parameters expect
         for k, v in accepets_payloads.items():
             _dict[k] = v
@@ -940,12 +948,16 @@ class WrapperBase(metaclass=Metaclass):
         reqDat
         ret:错误码。无错误码时返回0
     '''
+    def wrapperLoadRes(self, reqData: DataListCls, resId: int) -> int:
+        return 0
 
-    def wrapperOnceExec(cls, params: {}, reqData: DataListCls) -> Response:
+    def wrapperUnloadRes(self, resId: int) -> int:
+        return 0
+    def wrapperOnceExec(cls, params: {}, reqData: DataListCls, usrTag: str = "", persId: int = 0) -> Response:
         raise NotImplementedError(
             "Please Inplement Wrapper Class Method: wrapperOnceExec(cls, usrTag: str, params: {}, reqData: [], respData: [], psrIds: [], psrCnt: int) ")
 
-    def wrapperOnceExecAsync(cls, params: {}, reqData: DataListCls, sid: str) -> Response:
+    def wrapperOnceExecAsync(cls, params: {}, reqData: DataListCls, sid: str, persId: int = 0) -> Response:
         raise NotImplementedError(
             "Please Inplement Wrapper Class Method: wrapperOnceExec(cls, usrTag: str, params: {}, reqData: [], respData: [], psrIds: [], psrCnt: int) ")
 
@@ -958,7 +970,7 @@ class WrapperBase(metaclass=Metaclass):
         保留接口
     '''
 
-    def wrapperCreate(cls, params: {}, sid: str, userTag: str = "") -> SessionCreateResponse:
+    def wrapperCreate(cls, params: {}, sid: str, userTag: str = "", persId: int = 0) -> SessionCreateResponse:
         print(params)
 
         print(sid)
@@ -1015,6 +1027,26 @@ class WrapperBase(metaclass=Metaclass):
             log.error("invalid keys %s" % str(keys))
             return False
 
+        # check status
+        for d in resp.list:
+            if d.status != Once:
+                log.error("ResponseData 's data field status is %d, not %d. Modify it " % (d.status, Once))
+                return False
+
+        # check output datatype match
+        accepts = {}
+        for k in self.__mappings__['accepts']:
+            accepts[k.key] = k.data_type
+        for d in resp.list:
+            if d.key not in accepts:
+                log.error("ResponseData 's data field key %s is not in expect, Please check UserResponse " % (d.key))
+                return False
+            if d.type != accepts[d.key]:
+                log.error(
+                    "ResponseData 's data field , key: %s, data_type %s is not in expect, Please check UserResponse " % (
+                        d.key, d.type))
+                return False
+
         return True
 
     def run(self, stream=False):
